Building interaction lists
==========================

.. automodule:: boxtree.traversal

Traversal data structure
------------------------

.. autoclass:: FMMTraversalInfo()

    .. automethod:: get

    .. automethod:: merge_close_lists

Build Entrypoint
----------------

.. autoclass:: FMMTraversalBuilder

    .. automethod:: __call__


.. automodule:: boxtree.rotation_classes

Rotation classes data structure
-------------------------------

.. autoclass:: RotationClassesInfo

Build rotation classes
----------------------

.. autoclass:: RotationClassesBuilder

    .. automethod:: __call__


.. automodule:: boxtree.translation_classes

Translation classes data structure
----------------------------------

.. autoclass:: TranslationClassesInfo

Build translation classes
-------------------------

.. autoclass:: TranslationClassesBuilder

    .. automethod:: __call__

.. vim: sw=4
